==> webkit2gtk_2.17.91.orig.tar.xz: webkitgtk-2.17.91/Source/WebKit/NetworkProcess/Downloads/BlobDownloadClient.h <==
/*
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if !USE(NETWORK_SESSION)

#include <WebCore/FileSystem.h>
#include <WebCore/ResourceHandleClient.h>
#include <wtf/RefPtr.h>

namespace WebKit {

class Download;
class NetworkLoadParameters;

class BlobDownloadClient final : public WebCore::ResourceHandleClient {
public:
    explicit BlobDownloadClient(Download&);

    void didCancel();
    void didDecideDownloadDestination(const String& destinationPath, bool allowOverwrite);

private:
    // ResourceHandleClient
    void didReceiveResponseAsync(WebCore::ResourceHandle*, WebCore::ResourceResponse&&) final;
    void didReceiveBuffer(WebCore::ResourceHandle*, Ref<WebCore::SharedBuffer>&&, int reportedEncodedDataLength) final;
    void didFinishLoading(WebCore::ResourceHandle*) final;
    void didFail(WebCore::ResourceHandle*, const WebCore::ResourceError&) final;
    bool usesAsyncCallbacks() final { return true; }

    Download& m_download;
    String m_destinationPath;
    WebCore::PlatformFileHandle m_destinationFile { WebCore::invalidPlatformFileHandle };
};

}

#endif // !USE(NETWORK_SESSION)

==> webkit2gtk_2.19.3.orig.tar.xz: webkitgtk-2.19.3/Source/WebKit/NetworkProcess/Downloads/BlobDownloadClient.h <==
/*
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if !USE(NETWORK_SESSION)

#include <WebCore/FileSystem.h>
#include <WebCore/ResourceHandleClient.h>
#include <wtf/RefPtr.h>

namespace WebKit {

class Download;
class NetworkLoadParameters;

class BlobDownloadClient final : public WebCore::ResourceHandleClient {
public:
    explicit BlobDownloadClient(Download&);

    void didCancel();
    void didDecideDownloadDestination(const String& destinationPath, bool allowOverwrite);

private:
    // ResourceHandleClient
    void didReceiveResponseAsync(WebCore::ResourceHandle*, WebCore::ResourceResponse&&) final;
    void didReceiveBuffer(WebCore::ResourceHandle*, Ref<WebCore::SharedBuffer>&&, int reportedEncodedDataLength) final;
    void didFinishLoading(WebCore::ResourceHandle*) final;
    void didFail(WebCore::ResourceHandle*, const WebCore::ResourceError&) final;
    void willSendRequestAsync(WebCore::ResourceHandle*, WebCore::ResourceRequest&&, WebCore::ResourceResponse&&, CompletionHandler<void(WebCore::ResourceRequest&&)>&&) final;
#if USE(PROTECTION_SPACE_AUTH_CALLBACK)
    void canAuthenticateAgainstProtectionSpaceAsync(WebCore::ResourceHandle*, const WebCore::ProtectionSpace&) final;
#endif

    Download& m_download;
    String m_destinationPath;
    WebCore::FileSystem::PlatformFileHandle m_destinationFile { WebCore::FileSystem::invalidPlatformFileHandle };
};

}

#endif // !USE(NETWORK_SESSION)
